@@ -35,7 +35,6 @@ class ConfigurationTransformers:
         self.access_level_transformer = AccessLevelsTransformer(gitlab)
 
     def transform(self, configuration: Configuration) -> None:
-
         config_before = ez_yaml.to_string(obj=configuration.config, options={})
         debug(f"Config BEFORE transformations:\n{config_before}")
 
@@ -120,6 +119,19 @@ class GroupTransformer(ConfigurationTransformer):
         logging_args = SimpleNamespace(quiet=False, verbose=False, debug=False)
         processor = Processor(ConsolePrinter(logging_args), configuration.config)
 
+        try:
+            for node_coordinate in processor.get_nodes(
+                "projects_and_groups.*.protected_environments.*.deploy_access_levels.group",
+                mustexist=True,
+            ):
+                group = node_coordinate.parent.pop("group")
+                node_coordinate.parent["group_id"] = self.gitlab._get_group_id(group)
+
+        except YAMLPathException as e:
+            # this just means that we haven't found any keys in YAML
+            # under the given path
+            pass
+
         try:
             for node_coordinate in processor.get_nodes(
                 "**.merge_requests_approval_rules.*.groups",
