@@ -10,14 +10,12 @@ class GitLabGroups(GitLabCore):
         return self.get_group_case_insensitive(some_string)["id"]
 
     def get_group_case_insensitive(self, some_string):
-
         # maybe "foo/bar" is some group's path
 
         try:
             # try with exact case
             return self.get_group(some_string)
         except NotFoundException:
-
             # try case insensitive
             groups = self._make_requests_to_api(
                 "groups?search=%s",
@@ -60,7 +58,7 @@ class GitLabGroups(GitLabCore):
         """
         :return: sorted list of groups
         """
-        result = self._make_requests_to_api("groups?all_available=true", paginated=True)
+        result = self._make_requests_to_api("groups?all_available=true")
         return sorted(map(lambda x: x["full_path"], result))
 
     def get_projects(self, group, include_archived=False, only_names=True):
@@ -81,7 +79,7 @@ class GitLabGroups(GitLabCore):
                 query_string = "include_subgroups=true&archived=false"
 
             projects = self._make_requests_to_api(
-                f"groups/%s/projects?{query_string}", group, paginated=True
+                f"groups/%s/projects?{query_string}", group
             )
         except NotFoundException:
             projects = []
